Class: Aws::Cloud9::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Cloud9::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-cloud9/client.rb,
sig/client.rbs
Overview
An API client for Cloud9. To construct a client, you need to configure a :region and :credentials.
client = Aws::Cloud9::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateEnvironmentEC2ResponseSuccess, _CreateEnvironmentMembershipResponseSuccess, _DeleteEnvironmentMembershipResponseSuccess, _DeleteEnvironmentResponseSuccess, _DescribeEnvironmentMembershipsResponseSuccess, _DescribeEnvironmentStatusResponseSuccess, _DescribeEnvironmentsResponseSuccess, _ListEnvironmentsResponseSuccess, _ListTagsForResourceResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateEnvironmentMembershipResponseSuccess, _UpdateEnvironmentResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_environment_ec2(params = {}) ⇒ Types::CreateEnvironmentEC2Result
Creates an Cloud9 development environment, launches an Amazon Elastic Compute Cloud (Amazon EC2) instance, and then connects from the instance to the environment.
-
#create_environment_membership(params = {}) ⇒ Types::CreateEnvironmentMembershipResult
Adds an environment member to an Cloud9 development environment.
-
#delete_environment(params = {}) ⇒ Struct
Deletes an Cloud9 development environment.
-
#delete_environment_membership(params = {}) ⇒ Struct
Deletes an environment member from a development environment.
-
#describe_environment_memberships(params = {}) ⇒ Types::DescribeEnvironmentMembershipsResult
Gets information about environment members for an Cloud9 development environment.
-
#describe_environment_status(params = {}) ⇒ Types::DescribeEnvironmentStatusResult
Gets status information for an Cloud9 development environment.
-
#describe_environments(params = {}) ⇒ Types::DescribeEnvironmentsResult
Gets information about Cloud9 development environments.
-
#list_environments(params = {}) ⇒ Types::ListEnvironmentsResult
Gets a list of Cloud9 development environment identifiers.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets a list of the tags associated with an Cloud9 development environment.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to an Cloud9 development environment.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from an Cloud9 development environment.
-
#update_environment(params = {}) ⇒ Struct
Changes the settings of an existing Cloud9 development environment.
-
#update_environment_membership(params = {}) ⇒ Types::UpdateEnvironmentMembershipResult
Changes the settings of an existing environment member for an Cloud9 development environment.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-cloud9/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1449 1450 1451 |
# File 'lib/aws-sdk-cloud9/client.rb', line 1449 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1452 1453 1454 |
# File 'lib/aws-sdk-cloud9/client.rb', line 1452 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 |
# File 'lib/aws-sdk-cloud9/client.rb', line 1422 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Cloud9') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-cloud9' context[:gem_version] = '1.104.0' Seahorse::Client::Request.new(handlers, context) end |
#create_environment_ec2(params = {}) ⇒ Types::CreateEnvironmentEC2Result
Creates an Cloud9 development environment, launches an Amazon Elastic Compute Cloud (Amazon EC2) instance, and then connects from the instance to the environment.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. Learn more"
87 |
# File 'sig/client.rbs', line 87
def create_environment_ec2: (
|
#create_environment_membership(params = {}) ⇒ Types::CreateEnvironmentMembershipResult
Adds an environment member to an Cloud9 development environment.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. Learn more"
112 |
# File 'sig/client.rbs', line 112
def create_environment_membership: (
|
#delete_environment(params = {}) ⇒ Struct
Deletes an Cloud9 development environment. If an Amazon EC2 instance is connected to the environment, also terminates the instance.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. Learn more"
123 |
# File 'sig/client.rbs', line 123
def delete_environment: (
|
#delete_environment_membership(params = {}) ⇒ Struct
Deletes an environment member from a development environment.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. Learn more"
132 |
# File 'sig/client.rbs', line 132
def delete_environment_membership: (
|
#describe_environment_memberships(params = {}) ⇒ Types::DescribeEnvironmentMembershipsResult
Gets information about environment members for an Cloud9 development environment.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. Learn more"
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
144 |
# File 'sig/client.rbs', line 144
def describe_environment_memberships: (
|
#describe_environment_status(params = {}) ⇒ Types::DescribeEnvironmentStatusResult
Gets status information for an Cloud9 development environment.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. Learn more"
159 |
# File 'sig/client.rbs', line 159
def describe_environment_status: (
|
#describe_environments(params = {}) ⇒ Types::DescribeEnvironmentsResult
Gets information about Cloud9 development environments.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. Learn more"
169 |
# File 'sig/client.rbs', line 169
def describe_environments: (
|
#list_environments(params = {}) ⇒ Types::ListEnvironmentsResult
Gets a list of Cloud9 development environment identifiers.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. Learn more"
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. Learn more"
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
180 |
# File 'sig/client.rbs', line 180
def list_environments: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets a list of the tags associated with an Cloud9 development environment.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. Learn more"
191 |
# File 'sig/client.rbs', line 191
def list_tags_for_resource: (
|
#tag_resource(params = {}) ⇒ Struct
Adds tags to an Cloud9 development environment.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. Learn more"
Tags that you add to an Cloud9 environment by using this method will NOT be automatically propagated to underlying resources.
200 |
# File 'sig/client.rbs', line 200
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from an Cloud9 development environment.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. Learn more"
215 |
# File 'sig/client.rbs', line 215
def untag_resource: (
|
#update_environment(params = {}) ⇒ Struct
Changes the settings of an existing Cloud9 development environment.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. Learn more"
225 |
# File 'sig/client.rbs', line 225
def update_environment: (
|
#update_environment_membership(params = {}) ⇒ Types::UpdateEnvironmentMembershipResult
Changes the settings of an existing environment member for an Cloud9 development environment.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. Learn more"
238 |
# File 'sig/client.rbs', line 238
def update_environment_membership: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1442 1443 1444 |
# File 'lib/aws-sdk-cloud9/client.rb', line 1442 def waiter_names [] end |