Class: Aws::Cloud9::Types::CreateEnvironmentEC2Request
- Inherits:
-
Struct
- Object
- Struct
- Aws::Cloud9::Types::CreateEnvironmentEC2Request
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloud9/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :tags]
Instance Attribute Summary collapse
-
#automatic_stop_time_minutes ⇒ Integer
The number of minutes until the running instance is shut down after the environment has last been used.
-
#client_request_token ⇒ String
A unique, case-sensitive string that helps Cloud9 to ensure this operation completes no more than one time.
-
#connection_type ⇒ String
The connection type used for connecting to an Amazon EC2 environment.
-
#description ⇒ String
The description of the environment to create.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#image_id ⇒ String
The identifier for the Amazon Machine Image (AMI) that's used to create the EC2 instance.
-
#instance_type ⇒ String
The type of instance to connect to the environment (for example,
t2.micro). -
#name ⇒ String
The name of the environment to create.
-
#owner_arn ⇒ String
The Amazon Resource Name (ARN) of the environment owner.
-
#subnet_id ⇒ String
The ID of the subnet in Amazon VPC that Cloud9 will use to communicate with the Amazon EC2 instance.
-
#tags ⇒ Array<Types::Tag>
An array of key-value pairs that will be associated with the new Cloud9 development environment.
Instance Attribute Details
#automatic_stop_time_minutes ⇒ Integer
The number of minutes until the running instance is shut down after the environment has last been used.
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/aws-sdk-cloud9/types.rb', line 136 class CreateEnvironmentEC2Request < Struct.new( :name, :description, :client_request_token, :instance_type, :subnet_id, :image_id, :automatic_stop_time_minutes, :owner_arn, :tags, :connection_type, :dry_run) SENSITIVE = [:description, :tags] include Aws::Structure end |
#client_request_token ⇒ String
A unique, case-sensitive string that helps Cloud9 to ensure this operation completes no more than one time.
For more information, see Client Tokens in the Amazon EC2 API Reference.
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/aws-sdk-cloud9/types.rb', line 136 class CreateEnvironmentEC2Request < Struct.new( :name, :description, :client_request_token, :instance_type, :subnet_id, :image_id, :automatic_stop_time_minutes, :owner_arn, :tags, :connection_type, :dry_run) SENSITIVE = [:description, :tags] include Aws::Structure end |
#connection_type ⇒ String
The connection type used for connecting to an Amazon EC2
environment. Valid values are CONNECT_SSH (default) and
CONNECT_SSM (connected through Amazon EC2 Systems Manager).
For more information, see Accessing no-ingress EC2 instances with Amazon EC2 Systems Manager in the Cloud9 User Guide.
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/aws-sdk-cloud9/types.rb', line 136 class CreateEnvironmentEC2Request < Struct.new( :name, :description, :client_request_token, :instance_type, :subnet_id, :image_id, :automatic_stop_time_minutes, :owner_arn, :tags, :connection_type, :dry_run) SENSITIVE = [:description, :tags] include Aws::Structure end |
#description ⇒ String
The description of the environment to create.
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/aws-sdk-cloud9/types.rb', line 136 class CreateEnvironmentEC2Request < Struct.new( :name, :description, :client_request_token, :instance_type, :subnet_id, :image_id, :automatic_stop_time_minutes, :owner_arn, :tags, :connection_type, :dry_run) SENSITIVE = [:description, :tags] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/aws-sdk-cloud9/types.rb', line 136 class CreateEnvironmentEC2Request < Struct.new( :name, :description, :client_request_token, :instance_type, :subnet_id, :image_id, :automatic_stop_time_minutes, :owner_arn, :tags, :connection_type, :dry_run) SENSITIVE = [:description, :tags] include Aws::Structure end |
#image_id ⇒ String
The identifier for the Amazon Machine Image (AMI) that's used to create the EC2 instance. To choose an AMI for the instance, you must specify a valid AMI alias or a valid Amazon EC2 Systems Manager (SSM) path.
We recommend using Amazon Linux 2023 as the AMI to create your environment as it is fully supported.
From December 16, 2024, Ubuntu 18.04 will be removed from the list
of available imageIds for Cloud9. This change is necessary as
Ubuntu 18.04 has ended standard support on May 31, 2023. This change
will only affect direct API consumers, and not Cloud9 console users.
Since Ubuntu 18.04 has ended standard support as of May 31, 2023, we recommend you choose Ubuntu 22.04.
AMI aliases
-
Amazon Linux 2023 (recommended):
amazonlinux-2023-x86_64 -
Ubuntu 22.04:
ubuntu-22.04-x86_64
SSM paths
-
Amazon Linux 2023 (recommended):
resolve:ssm:/aws/service/cloud9/amis/amazonlinux-2023-x86_64 -
Ubuntu 22.04:
resolve:ssm:/aws/service/cloud9/amis/ubuntu-22.04-x86_64
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/aws-sdk-cloud9/types.rb', line 136 class CreateEnvironmentEC2Request < Struct.new( :name, :description, :client_request_token, :instance_type, :subnet_id, :image_id, :automatic_stop_time_minutes, :owner_arn, :tags, :connection_type, :dry_run) SENSITIVE = [:description, :tags] include Aws::Structure end |
#instance_type ⇒ String
The type of instance to connect to the environment (for example,
t2.micro).
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/aws-sdk-cloud9/types.rb', line 136 class CreateEnvironmentEC2Request < Struct.new( :name, :description, :client_request_token, :instance_type, :subnet_id, :image_id, :automatic_stop_time_minutes, :owner_arn, :tags, :connection_type, :dry_run) SENSITIVE = [:description, :tags] include Aws::Structure end |
#name ⇒ String
The name of the environment to create.
This name is visible to other IAM users in the same Amazon Web Services account.
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/aws-sdk-cloud9/types.rb', line 136 class CreateEnvironmentEC2Request < Struct.new( :name, :description, :client_request_token, :instance_type, :subnet_id, :image_id, :automatic_stop_time_minutes, :owner_arn, :tags, :connection_type, :dry_run) SENSITIVE = [:description, :tags] include Aws::Structure end |
#owner_arn ⇒ String
The Amazon Resource Name (ARN) of the environment owner. This ARN can be the ARN of any IAM principal. If this value is not specified, the ARN defaults to this environment's creator.
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/aws-sdk-cloud9/types.rb', line 136 class CreateEnvironmentEC2Request < Struct.new( :name, :description, :client_request_token, :instance_type, :subnet_id, :image_id, :automatic_stop_time_minutes, :owner_arn, :tags, :connection_type, :dry_run) SENSITIVE = [:description, :tags] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the subnet in Amazon VPC that Cloud9 will use to communicate with the Amazon EC2 instance.
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/aws-sdk-cloud9/types.rb', line 136 class CreateEnvironmentEC2Request < Struct.new( :name, :description, :client_request_token, :instance_type, :subnet_id, :image_id, :automatic_stop_time_minutes, :owner_arn, :tags, :connection_type, :dry_run) SENSITIVE = [:description, :tags] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of key-value pairs that will be associated with the new Cloud9 development environment.
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/aws-sdk-cloud9/types.rb', line 136 class CreateEnvironmentEC2Request < Struct.new( :name, :description, :client_request_token, :instance_type, :subnet_id, :image_id, :automatic_stop_time_minutes, :owner_arn, :tags, :connection_type, :dry_run) SENSITIVE = [:description, :tags] include Aws::Structure end |