Class: Aws::Cloud9::Types::Environment
- Inherits:
-
Struct
- Object
- Struct
- Aws::Cloud9::Types::Environment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloud9/types.rb
Overview
Information about an Cloud9 development environment.
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the environment.
-
#connection_type ⇒ String
The connection type used for connecting to an Amazon EC2 environment.
-
#description ⇒ String
The description for the environment.
-
#id ⇒ String
The ID of the environment.
-
#lifecycle ⇒ Types::EnvironmentLifecycle
The state of the environment in its creation or deletion lifecycle.
-
#managed_credentials_status ⇒ String
Describes the status of Amazon Web Services managed temporary credentials for the Cloud9 environment.
-
#name ⇒ String
The name of the environment.
-
#owner_arn ⇒ String
The Amazon Resource Name (ARN) of the environment owner.
-
#type ⇒ String
The type of environment.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the environment.
448 449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/aws-sdk-cloud9/types.rb', line 448 class Environment < Struct.new( :id, :name, :description, :type, :connection_type, :arn, :owner_arn, :lifecycle, :managed_credentials_status) SENSITIVE = [:description] include Aws::Structure end |
#connection_type ⇒ String
The connection type used for connecting to an Amazon EC2
environment. CONNECT_SSH is selected by default.
448 449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/aws-sdk-cloud9/types.rb', line 448 class Environment < Struct.new( :id, :name, :description, :type, :connection_type, :arn, :owner_arn, :lifecycle, :managed_credentials_status) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description for the environment.
448 449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/aws-sdk-cloud9/types.rb', line 448 class Environment < Struct.new( :id, :name, :description, :type, :connection_type, :arn, :owner_arn, :lifecycle, :managed_credentials_status) SENSITIVE = [:description] include Aws::Structure end |
#id ⇒ String
The ID of the environment.
448 449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/aws-sdk-cloud9/types.rb', line 448 class Environment < Struct.new( :id, :name, :description, :type, :connection_type, :arn, :owner_arn, :lifecycle, :managed_credentials_status) SENSITIVE = [:description] include Aws::Structure end |
#lifecycle ⇒ Types::EnvironmentLifecycle
The state of the environment in its creation or deletion lifecycle.
448 449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/aws-sdk-cloud9/types.rb', line 448 class Environment < Struct.new( :id, :name, :description, :type, :connection_type, :arn, :owner_arn, :lifecycle, :managed_credentials_status) SENSITIVE = [:description] include Aws::Structure end |
#managed_credentials_status ⇒ String
Describes the status of Amazon Web Services managed temporary credentials for the Cloud9 environment. Available values are:
-
ENABLED_ON_CREATE -
ENABLED_BY_OWNER -
DISABLED_BY_DEFAULT -
DISABLED_BY_OWNER -
DISABLED_BY_COLLABORATOR -
PENDING_REMOVAL_BY_COLLABORATOR -
PENDING_REMOVAL_BY_OWNER -
FAILED_REMOVAL_BY_COLLABORATOR -
ENABLED_BY_OWNER -
DISABLED_BY_DEFAULT
448 449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/aws-sdk-cloud9/types.rb', line 448 class Environment < Struct.new( :id, :name, :description, :type, :connection_type, :arn, :owner_arn, :lifecycle, :managed_credentials_status) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
The name of the environment.
448 449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/aws-sdk-cloud9/types.rb', line 448 class Environment < Struct.new( :id, :name, :description, :type, :connection_type, :arn, :owner_arn, :lifecycle, :managed_credentials_status) SENSITIVE = [:description] include Aws::Structure end |
#owner_arn ⇒ String
The Amazon Resource Name (ARN) of the environment owner.
448 449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/aws-sdk-cloud9/types.rb', line 448 class Environment < Struct.new( :id, :name, :description, :type, :connection_type, :arn, :owner_arn, :lifecycle, :managed_credentials_status) SENSITIVE = [:description] include Aws::Structure end |
#type ⇒ String
The type of environment. Valid values include the following:
-
ec2: An Amazon Elastic Compute Cloud (Amazon EC2) instance connects to the environment. -
ssh: Your own server connects to the environment.
448 449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/aws-sdk-cloud9/types.rb', line 448 class Environment < Struct.new( :id, :name, :description, :type, :connection_type, :arn, :owner_arn, :lifecycle, :managed_credentials_status) SENSITIVE = [:description] include Aws::Structure end |