Class: Aws::Cloud9::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Cloud9::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-cloud9/client.rb
Overview
An API client for Cloud9. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Cloud9::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_environment_ec2(params = {}) ⇒ Types::CreateEnvironmentEC2Result
Creates an Cloud9 development environment, launches an Amazon Elastic Compute Cloud (Amazon EC2) instance, and then connects from the instance to the environment.
-
#create_environment_membership(params = {}) ⇒ Types::CreateEnvironmentMembershipResult
Adds an environment member to an Cloud9 development environment.
-
#delete_environment(params = {}) ⇒ Struct
Deletes an Cloud9 development environment.
-
#delete_environment_membership(params = {}) ⇒ Struct
Deletes an environment member from a development environment.
-
#describe_environment_memberships(params = {}) ⇒ Types::DescribeEnvironmentMembershipsResult
Gets information about environment members for an Cloud9 development environment.
-
#describe_environment_status(params = {}) ⇒ Types::DescribeEnvironmentStatusResult
Gets status information for an Cloud9 development environment.
-
#describe_environments(params = {}) ⇒ Types::DescribeEnvironmentsResult
Gets information about Cloud9 development environments.
-
#list_environments(params = {}) ⇒ Types::ListEnvironmentsResult
Gets a list of Cloud9 development environment identifiers.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets a list of the tags associated with an Cloud9 development environment.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to an Cloud9 development environment.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from an Cloud9 development environment.
-
#update_environment(params = {}) ⇒ Struct
Changes the settings of an existing Cloud9 development environment.
-
#update_environment_membership(params = {}) ⇒ Types::UpdateEnvironmentMembershipResult
Changes the settings of an existing environment member for an Cloud9 development environment.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-cloud9/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1459 1460 1461 |
# File 'lib/aws-sdk-cloud9/client.rb', line 1459 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1462 1463 1464 |
# File 'lib/aws-sdk-cloud9/client.rb', line 1462 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 |
# File 'lib/aws-sdk-cloud9/client.rb', line 1432 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Cloud9') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-cloud9' context[:gem_version] = '1.103.0' Seahorse::Client::Request.new(handlers, context) end |
#create_environment_ec2(params = {}) ⇒ Types::CreateEnvironmentEC2Result
Creates an Cloud9 development environment, launches an Amazon Elastic Compute Cloud (Amazon EC2) instance, and then connects from the instance to the environment.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. [Learn more“]
[1]: aws.amazon.com/blogs/devops/how-to-migrate-from-aws-cloud9-to-aws-ide-toolkits-or-aws-cloudshell/
648 649 650 651 |
# File 'lib/aws-sdk-cloud9/client.rb', line 648 def create_environment_ec2(params = {}, = {}) req = build_request(:create_environment_ec2, params) req.send_request() end |
#create_environment_membership(params = {}) ⇒ Types::CreateEnvironmentMembershipResult
Adds an environment member to an Cloud9 development environment.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. [Learn more“]
[1]: aws.amazon.com/blogs/devops/how-to-migrate-from-aws-cloud9-to-aws-ide-toolkits-or-aws-cloudshell/
721 722 723 724 |
# File 'lib/aws-sdk-cloud9/client.rb', line 721 def create_environment_membership(params = {}, = {}) req = build_request(:create_environment_membership, params) req.send_request() end |
#delete_environment(params = {}) ⇒ Struct
Deletes an Cloud9 development environment. If an Amazon EC2 instance is connected to the environment, also terminates the instance.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. [Learn more“]
[1]: aws.amazon.com/blogs/devops/how-to-migrate-from-aws-cloud9-to-aws-ide-toolkits-or-aws-cloudshell/
762 763 764 765 |
# File 'lib/aws-sdk-cloud9/client.rb', line 762 def delete_environment(params = {}, = {}) req = build_request(:delete_environment, params) req.send_request() end |
#delete_environment_membership(params = {}) ⇒ Struct
Deletes an environment member from a development environment.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. [Learn more“]
[1]: aws.amazon.com/blogs/devops/how-to-migrate-from-aws-cloud9-to-aws-ide-toolkits-or-aws-cloudshell/
808 809 810 811 |
# File 'lib/aws-sdk-cloud9/client.rb', line 808 def delete_environment_membership(params = {}, = {}) req = build_request(:delete_environment_membership, params) req.send_request() end |
#describe_environment_memberships(params = {}) ⇒ Types::DescribeEnvironmentMembershipsResult
Gets information about environment members for an Cloud9 development environment.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. [Learn more“]
[1]: aws.amazon.com/blogs/devops/how-to-migrate-from-aws-cloud9-to-aws-ide-toolkits-or-aws-cloudshell/
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
965 966 967 968 |
# File 'lib/aws-sdk-cloud9/client.rb', line 965 def describe_environment_memberships(params = {}, = {}) req = build_request(:describe_environment_memberships, params) req.send_request() end |
#describe_environment_status(params = {}) ⇒ Types::DescribeEnvironmentStatusResult
Gets status information for an Cloud9 development environment.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. [Learn more“]
[1]: aws.amazon.com/blogs/devops/how-to-migrate-from-aws-cloud9-to-aws-ide-toolkits-or-aws-cloudshell/
1015 1016 1017 1018 |
# File 'lib/aws-sdk-cloud9/client.rb', line 1015 def describe_environment_status(params = {}, = {}) req = build_request(:describe_environment_status, params) req.send_request() end |
#describe_environments(params = {}) ⇒ Types::DescribeEnvironmentsResult
Gets information about Cloud9 development environments.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. [Learn more“]
[1]: aws.amazon.com/blogs/devops/how-to-migrate-from-aws-cloud9-to-aws-ide-toolkits-or-aws-cloudshell/
1099 1100 1101 1102 |
# File 'lib/aws-sdk-cloud9/client.rb', line 1099 def describe_environments(params = {}, = {}) req = build_request(:describe_environments, params) req.send_request() end |
#list_environments(params = {}) ⇒ Types::ListEnvironmentsResult
Gets a list of Cloud9 development environment identifiers.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. [Learn more“]
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. [Learn more“]
[1]: aws.amazon.com/blogs/devops/how-to-migrate-from-aws-cloud9-to-aws-ide-toolkits-or-aws-cloudshell/
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1166 1167 1168 1169 |
# File 'lib/aws-sdk-cloud9/client.rb', line 1166 def list_environments(params = {}, = {}) req = build_request(:list_environments, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets a list of the tags associated with an Cloud9 development environment.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. [Learn more“]
[1]: aws.amazon.com/blogs/devops/how-to-migrate-from-aws-cloud9-to-aws-ide-toolkits-or-aws-cloudshell/
1205 1206 1207 1208 |
# File 'lib/aws-sdk-cloud9/client.rb', line 1205 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to an Cloud9 development environment.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. [Learn more“]
Tags that you add to an Cloud9 environment by using this method will NOT be automatically propagated to underlying resources.
[1]: aws.amazon.com/blogs/devops/how-to-migrate-from-aws-cloud9-to-aws-ide-toolkits-or-aws-cloudshell/
1247 1248 1249 1250 |
# File 'lib/aws-sdk-cloud9/client.rb', line 1247 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from an Cloud9 development environment.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. [Learn more“]
[1]: aws.amazon.com/blogs/devops/how-to-migrate-from-aws-cloud9-to-aws-ide-toolkits-or-aws-cloudshell/
1282 1283 1284 1285 |
# File 'lib/aws-sdk-cloud9/client.rb', line 1282 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_environment(params = {}) ⇒ Struct
Changes the settings of an existing Cloud9 development environment.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. [Learn more“]
[1]: aws.amazon.com/blogs/devops/how-to-migrate-from-aws-cloud9-to-aws-ide-toolkits-or-aws-cloudshell/
1349 1350 1351 1352 |
# File 'lib/aws-sdk-cloud9/client.rb', line 1349 def update_environment(params = {}, = {}) req = build_request(:update_environment, params) req.send_request() end |
#update_environment_membership(params = {}) ⇒ Types::UpdateEnvironmentMembershipResult
Changes the settings of an existing environment member for an Cloud9 development environment.
Cloud9 is no longer available to new customers. Existing customers of Cloud9 can continue to use the service as normal. [Learn more“]
[1]: aws.amazon.com/blogs/devops/how-to-migrate-from-aws-cloud9-to-aws-ide-toolkits-or-aws-cloudshell/
1423 1424 1425 1426 |
# File 'lib/aws-sdk-cloud9/client.rb', line 1423 def update_environment_membership(params = {}, = {}) req = build_request(:update_environment_membership, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1452 1453 1454 |
# File 'lib/aws-sdk-cloud9/client.rb', line 1452 def waiter_names [] end |